@@ -16,6 +16,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper
 
     m_pSession = pSession; //set the Spotify session instance
     m_playing = false; //set initial playback state
+    m_tokenLost = false; //set inital token state
     m_userInitiatedPause = false;
     m_pauseOnHsetUnplugged = false;
     m_update = false;
@@ -82,6 +83,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper
     connect(m_pSession,SIGNAL(playing(bool)),SLOT(OnPlayingState(bool)));
     connect(m_pSession,SIGNAL(playbackFinished()),SLOT(OnTrackPlaybackFinished()));
     connect(m_pSession,SIGNAL(bufferNextTrack()),SLOT(OnBufferNextTrack()));
+    connect(m_pSession,SIGNAL(playTokenLost()),SLOT(OnPlaybackTokenLost()));
     connect(m_pTrackInfoView,SIGNAL(activated(QModelIndex)),SLOT(OnTrackActivated(QModelIndex)));
     connect(&m_PauseResumeBtn,SIGNAL(clicked()),SLOT(OnPauseResumeToggle()));
     connect(&m_ShuffleBtn,SIGNAL(clicked()),SLOT(OnShuffleToggle()));
@@ -245,7 +247,6 @@ void QueueView::setListViewState()
 void QueueView::OnPlaybackStateChangeRequest(enum pb_state_e requestedState)
 {
    //request received via libplayback asking for a playback state change
-    qDebug() << "Got here..";
     if(((requestedState==PB_STATE_STOP)||(requestedState==PB_STATE_PLAY)) && !m_userInitiatedPause)
     { //request to move to stopped state, pause current playback
         qDebug() << "Request to pause / resume .. (state:" << requestedState << "), pause state: " << m_userInitiatedPause;
@@ -601,6 +602,8 @@ void QueueView::OnPauseResumeToggle()
 {
     //Play / Pause button has bee clicked (toggled)
 
+    Spotify::Error err;
+
     if(m_pCurrTrack) //some track has been activated
     {
         if(m_playbackStateChangeReq)
@@ -617,6 +620,12 @@ void QueueView::OnPauseResumeToggle()
         {
             m_userInitiatedPause = false;
         }
+        if(m_tokenLost)
+        {//token has been lost; send request to regain the playback token
+           err =  m_pSession->pauseResumeBuffering();
+           if(!err.isError())
+               m_tokenLost = false;
+        }
         m_pSession->pauseResumePlayback(); //pause / resume playback of current track
     }
 }
@@ -640,7 +649,7 @@ void QueueView::pauseResumePlayback()
 
 void QueueView::OnNextTrackBtn()
 {
-    //move to next track in play queue
+    //move to next track in the play queue
 
     Spotify::Error error;
 
@@ -669,6 +678,10 @@ void QueueView::OnNextTrackBtn()
         {
             m_currQueuePos++;
         }
+        else
+        {
+            m_currShuffleBuffPos = m_currShufflePos;
+        }
         m_currQueueBuffPos = m_currQueuePos;
         QStandardItem* prevTrackItem = m_pTrackInfoModel->item(oldQueuePos); //get previously selected item
         if(prevTrackItem)
@@ -713,6 +726,10 @@ void QueueView::OnPrevTrackBtn()
         {
             m_currQueuePos--;
         }
+        else
+        {
+            m_currShuffleBuffPos = m_currShufflePos;
+        }
         m_currQueueBuffPos = m_currQueuePos;
         QStandardItem* prevTrackItem = m_pTrackInfoModel->item(oldQueuePos); //get previously selected item
         if(prevTrackItem)
@@ -1130,6 +1147,14 @@ void QueueView::OnHeadsetRemoved()
     }
 }
 
+void QueueView::OnPlaybackTokenLost()
+{
+    //Notification from session instance that playback token has been lost
+    m_tokenLost = true; //flag to indicate that we have lost the playback token
+    if(m_playing) //in case we are currently playing, request to stop playback and set UI elements to corresponding state
+        pauseResumePlayback();
+}
+
 /*void QueueView::OnProgressSliderClicked(int pos)
 {
     //progress slider has been clicked (pos=clicked position)
