@@ -133,6 +133,8 @@ private:
 
     bool m_playing; //TRUE in case currently in playing state
 
+    bool m_tokenLost; //TRUE in case we have lost the playback token
+
     bool m_update; //TRUE in case UI elements should be updated
 
     bool m_currTrackScrobbled; //TRUE in case the current track has been scrobbled (to Last.fm)
@@ -195,6 +197,7 @@ private slots:
     //void OnProgressSliderClicked(int pos); //progress slider has been clicked (pos=clicked position)
     void OnHalButtonPressed(const QString& value); //button pressed notification (condition) received from HAL (device)
     void OnHeadsetRemoved(); //headset removed notification from Hal device manager received
+    void OnPlaybackTokenLost(); //notification from session instance that playback token has been lost
 
 signals:
 
