@@ -39,6 +39,27 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_BufferingOptions.setLayout(&m_BufferingOptionLayout);
 
+    //set up login-related options
+
+    m_SaveCredentials.setText(tr("Remember UserID and password"));
+    m_LoginOptionLayout.addWidget(&m_SaveCredentials,0,0,1,-1);
+    m_LoginOptions.setLayout(&m_LoginOptionLayout);
+
+
+    //set up bitrate selection value button / selector
+
+    QStringListModel *pBitrateListModel = new QStringListModel(this);
+
+    m_bitrateList << tr("Low bitrate (96kbps)") << tr("Standard bitrate (160kbps)")
+            << tr("High bitrate (320kbps)");
+
+    pBitrateListModel->setStringList(m_bitrateList);
+
+    m_pPreferredBitrateSelector = new QMaemo5ListPickSelector(this);
+    m_pPreferredBitrateSelector->setModel(pBitrateListModel);
+    m_PreferredBitrateBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
+    m_PreferredBitrateBtn.setPickSelector(m_pPreferredBitrateSelector);
+
     //set up UI language value button / selector
 
     QStringListModel *pLangListModel = new QStringListModel(this);
@@ -71,7 +92,6 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_PlaylistLoadingTOInput.setInputMask("900");
 
-
     m_LastFMUserIDInput.setInputMethodHints(Qt::ImhNoAutoUppercase);
     m_LastFMPasswordInput.setEchoMode(QLineEdit::Password); //set password mode for input field
 
@@ -90,11 +110,13 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_GridLayout.addWidget(&m_SearchOptions,0,0,1,-1);
     m_GridLayout.addWidget(&m_BufferingOptions,1,0,1,-1);
-    m_GridLayout.addWidget(&m_UILangBtn,2,0,1,-1);
-    m_GridLayout.addWidget(&m_OrientationBtn,3,0,1,-1);
-    m_GridLayout.addWidget(&m_PlaylistOptions,4,0,1,-1);
-    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,5,0,1,-1);
-    m_GridLayout.addWidget(&m_ScrobblingOptions,6,0,1,-1);
+    m_GridLayout.addWidget(&m_LoginOptions,2,0,1,-1);
+    m_GridLayout.addWidget(&m_PreferredBitrateBtn,3,0,1,-1);
+    m_GridLayout.addWidget(&m_UILangBtn,4,0,1,-1);
+    m_GridLayout.addWidget(&m_OrientationBtn,5,0,1,-1);
+    m_GridLayout.addWidget(&m_PlaylistOptions,6,0,1,-1);
+    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,7,0,1,-1);
+    m_GridLayout.addWidget(&m_ScrobblingOptions,8,0,1,-1);
 
     m_MainAreaLayout.setLayout(&m_GridLayout);
     m_MainArea.setWidget(&m_MainAreaLayout);
@@ -123,6 +145,7 @@ void SettingsDialog::setCapsLandscape()
     m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_MinBufferLenCaption.setText(tr("Min. buffering length (secs)"));
     m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buffering"));
+    m_PreferredBitrateBtn.setText(tr("Preferred bitrate"));
     m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
     m_PlaylistOptions.setTitle(tr("Playlist options"));
@@ -147,6 +170,7 @@ void SettingsDialog::setCapsPortrait()
     m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_MinBufferLenCaption.setText(tr("Min.buff.length (secs)"));
     m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buff."));
+    m_PreferredBitrateBtn.setText(tr("Preferred bitrate"));
     m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
     m_PlaylistOptions.setTitle(tr("Playlist options"));
@@ -187,6 +211,19 @@ void SettingsDialog::readSettings()
         else
             m_PreBufferNextTrackSelection.setChecked(false);
 
+        m_saveCredentials = m_pAppSettings->value("QSpot/SaveCredentials",SAVE_CREDENTIALS_DEFAULT).toInt();
+        if(m_saveCredentials)
+        { //set save credentials checkbox
+            m_SaveCredentials.setChecked(true);
+        }
+        else
+        {
+            m_SaveCredentials.setChecked(false);
+        }
+
+        m_prefBitrate = m_pAppSettings->value("QSpot/PrefBitrate",IDX_BITRATE_160k).toInt();
+        m_pPreferredBitrateSelector->setCurrentIndex(m_prefBitrate);
+
         m_currUILang = m_UILangCodeList.indexOf(m_pAppSettings->value("QSpot/language",LANG_DEFAULT).toString());
         m_pUILangSelector->setCurrentIndex(m_currUILang);
 
@@ -269,6 +306,27 @@ void SettingsDialog::saveSettings()
             settingsChanged = true;
         }
 
+        if(m_SaveCredentials.isChecked() && !m_saveCredentials)
+        {
+            m_pAppSettings->setValue("QSpot/SaveCredentials",1);
+           // m_pAppSettings->setValue("QSpot/UserID",m_strUserID);
+            //m_pAppSettings->setValue("QSpot/Password",m_strUserPwd);
+            settingsChanged = true;
+        }
+        else if(!m_SaveCredentials.isChecked() && m_saveCredentials)
+        { //credentials should not be saved, remove any existing values
+            m_pAppSettings->setValue("QSpot/SaveCredentials",0);
+           // m_pAppSettings->setValue("QSpot/UserID","");
+            //m_pAppSettings->setValue("QSpot/Password","");
+            settingsChanged = true;
+        }
+
+        if(m_pPreferredBitrateSelector->currentIndex()!=m_prefBitrate)
+        {
+            m_pAppSettings->setValue("QSpot/PrefBitrate",m_pPreferredBitrateSelector->currentIndex());
+            QMaemo5InformationBox::information(this,tr("Please restart QSpot for bitrate change to take effect!"));
+        }
+
         if(m_pUILangSelector->currentIndex()!=m_currUILang)
         {
             m_pAppSettings->setValue("QSpot/language",m_UILangCodeList.at(m_pUILangSelector->currentIndex()));
