@@ -366,7 +366,7 @@ void TrackView::addTrackListModelItem(Spotify::Track* track, int pos)
     QString strSubHeader;
     QPixmap iconMap;
 
-    iconMap.load("/usr/share/images/icon-type-song-color.png"); //load song (track) type icon from file
+    iconMap.load("/opt/qspot/images/icon-type-song-color.png"); //load song (track) type icon from file
 
     QIcon trackTypeIcon(iconMap);
 
