@@ -163,7 +163,7 @@ void ArtistView::addAlbums()
 
     QPixmap iconMap;
 
-    iconMap.load("/usr/share/images/icon-type-album.png"); //load album type icon from file
+    iconMap.load("/opt/qspot/images/icon-type-album.png"); //load album type icon from file
 
     QIcon albumTypeIcon(iconMap);
 
