@@ -161,7 +161,49 @@ MainWindow::MainWindow(QWidget *parent)
 
     setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt()); //set initial display orientation for views / dialogs
 
-    emit showLogin(); //emit signal requesting to show login dialog
+    handleSpotifyLogin(); //handle login process
+}
+
+void MainWindow::handleSpotifyLogin()
+{
+   //Method for handling the login process to Spotify. Performs automatic-login in case user has specified that credentials should be saved;
+   //otherwise the login dialog is displayed.
+
+    QMessageBox msgBox;
+    sp_bitrate selectedBitrate;
+
+    if(m_pAppSettings->value("QSpot/SaveCredentials",SAVE_CREDENTIALS_DEFAULT).toInt())
+    {
+        //perform auto-login in case user has saved credentials
+
+        //read preferred bitrate from settings file
+        int prefBitrate = m_pAppSettings->value("QSpot/PrefBitrate",IDX_BITRATE_160k).toInt();
+        if(prefBitrate==IDX_BITRATE_96k)
+            selectedBitrate = SP_BITRATE_96k;
+        else if(prefBitrate==IDX_BITRATE_320k)
+            selectedBitrate = SP_BITRATE_320k;
+        else //default bitrate
+            selectedBitrate = SP_BITRATE_160k;
+
+        m_pSession->init(selectedBitrate); //init new session prior to login
+
+        QMaemo5InformationBox::information(this,tr("Logging in to Spotify"));
+        Spotify::Error err = m_pSession->login(m_pAppSettings->value("QSpot/UserID").toString(),m_pAppSettings->value("QSpot/Password").toString());
+        if(err.isError())
+        {
+            msgBox.setText(tr("Error:") + ":" + err.toString());
+            msgBox.exec();
+            emit showLogin(); //emit signal requesting to show login dialog
+        }
+        else
+        {
+            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+        }
+    }
+    else
+    {
+        emit showLogin(); //emit signal requesting to show login dialog
+    }
 }
 
 void MainWindow::setupUILang()
@@ -181,7 +223,8 @@ void MainWindow::initAboutDialog()
     m_AboutDlg.setText(tr("QSpot version ") + APP_VERSION + "\n\n" + tr("An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n"
                         "(C) 2011 Andreas Enbacka and The QSpot Team.\n\n"
                         "Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout, "
-                        "and to Tomi (rantom@tmo) for the Finnish translations."));
+                        "and to Tomi (rantom@tmo), Florian (florian@tmo) and Benno (bartus@tmo) for the translations."));
+
 
     QRect screenGeometry = QApplication::desktop()->screenGeometry(); // get current screen geometry
     if (screenGeometry.width() > screenGeometry.height())
@@ -228,6 +271,19 @@ void MainWindow::OnSettingsSaved()
         m_pSession->setPreBufferingActive(false);
     }
 
+    if(m_pAppSettings->value("QSpot/SaveCredentials",SAVE_CREDENTIALS_DEFAULT).toInt())
+    { //current session username and password should be saved to the settings file
+        m_pAppSettings->setValue("QSpot/UserID",m_pSession->getUserID()); //session UserID
+        m_pAppSettings->setValue("QSpot/Password",m_pSession->getUserPwd()); //session user password
+    }
+    else
+    {
+        //no settings should be saved, clear data in case previously set
+        m_pAppSettings->setValue("QSpot/UserID","");
+        m_pAppSettings->setValue("QSpot/Password","");
+    }
+
+
     //display orientation setting
     setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt());
 
@@ -403,10 +459,12 @@ void MainWindow::OnLoggedIn(Spotify::Error error)
 
     if(error.isError())
     {
+        setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide main window progress indicator
         strLoginMsg = tr("Error:") + error.toString(); //write error string
         msgBox.setText(strLoginMsg);
         msgBox.exec();
         m_pLoginDlg->resetState(); //re-enable login button etc.
+        emit showLogin(); //display login dialog in case auto-login is enabled and has failed
     }
     else
     { //successful login to Spotify service, request user playlist / track data
@@ -435,6 +493,8 @@ void MainWindow::OnPlaylistLoadingTimeout()
 
     QMaemo5InformationBox::information(this,tr("Timeout occured while loading playlists!")); //display timeout notification
 
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //disable progress indicator
+
     setupInitialState();
 }
 
