@@ -70,6 +70,18 @@ Spotify::Session::Session( QObject* parent ):
     m_bPlaylistsLoading = false;
 }
 
+QString Spotify::Session::getUserID()
+{
+    //Returns current UserID for the session
+    return m_username;
+}
+
+QString Spotify::Session::getUserPwd()
+{
+    //Returns current password for the session
+    return m_password;
+}
+
 void Spotify::Session::init(const sp_bitrate& bitrate)
 {
     //Init the current Spotify session.
@@ -389,6 +401,7 @@ Spotify::Error Spotify::Session::seek( qint32 pos )
 
 Spotify::Error Spotify::Session::stop()
 {
+    //stop playback (buffering) and unload the currently loaded track
     Spotify::Error error;
 
     if( m_playing )
@@ -396,9 +409,8 @@ Spotify::Error Spotify::Session::stop()
         error = sp_session_player_play( m_session, false );
         if( !error.isError() )
         {
-           // sleep.wait(&mutex,1500);
-            //sp_session_player_unload( m_session );
-            //m_playing = false;
+           // sp_session_player_unload( m_session );
+            m_playing = false;
         }
     }
     return error;
@@ -415,24 +427,24 @@ void Spotify::Session::pauseResumePlayback()
     m_pAudioThread->getMutex()->unlock();
 }
 
-Spotify::Error Spotify::Session::pause()
+Spotify::Error Spotify::Session::pauseResumeBuffering()
 {
-    //Pause music delivery from Spotify
+    //Pause / resume  music delivery (i.e., buffering) from  Spotify
 
     Spotify::Error error;
-    // Is playing:
 
+    //playing (buffering) music data
     if( m_playing )
-    {
+    { //pause buffering
         error = sp_session_player_play( m_session, false );
         if( !error.isError() )
         {
             m_playing = false;
         }
     }
-    // Is paused:
+    // buffering currently paused
     else if( !m_playing && m_currentTrack->getTrack() && sp_track_is_loaded( m_currentTrack->getTrack() ) )
-    {
+    { //resume buffering
         error = sp_session_player_play( m_session, true );
         if( !error.isError() )
         {
@@ -1331,7 +1343,7 @@ void Spotify::Session::OnMusicDelivery(int num_frames, const sp_audioformat* for
     {
         m_pAudioThread->setBufferingPaused(true);
         m_pAudioThread->getMutex()->unlock();
-        pause();
+        pauseResumeBuffering();
     }
     else
     {
@@ -1342,7 +1354,7 @@ void Spotify::Session::OnMusicDelivery(int num_frames, const sp_audioformat* for
 void Spotify::Session::OnResumeBuffering()
 {
     //signal from playback thread that more buffered data is needed
-    pause();
+    pauseResumeBuffering();
 }
 
 void Spotify::Session::playTokenLostCallback( sp_session* session )
@@ -1355,6 +1367,7 @@ void Spotify::Session::playTokenLostWrapper( sp_session* session )
     //emit signal when playback token has been lost (e.g., same account logs in somewhere else)
     Q_UNUSED( session );
     emit playTokenLost();
+    m_playing = false;
 }
 
 void Spotify::Session::logMessageCallback( sp_session* session, const char* message )
