@@ -31,6 +31,7 @@ namespace Spotify
         Q_OBJECT
         public:
 
+
             Session( QObject* parent = 0 );
             virtual ~Session();
 
@@ -64,6 +65,9 @@ namespace Spotify
 
             void resetPlaybackMembers();  //reset the playback related instance members (and removes any pending events from the playback thread)
 
+            QString getUserID(); //Returns current UserID for the session
+
+            QString getUserPwd(); //Returns current password for the session
 
             /**
              * Pointer to the Session object. Used to map
@@ -125,9 +129,9 @@ namespace Spotify
             Spotify::Error stop();
 
             /**
-             * Toggle music delivery pause from Spotify.
+             * Toggle music delivery (i.e., buffering) pause from Spotify.
              */
-            Spotify::Error pause();
+            Spotify::Error pauseResumeBuffering();
 
             /**
              * Toggle playback pause / resume (e.g, stop / continue writing data to PulseAudio).
